API docs for “spamfighter.core.domain”

# Module s.c.domain

Part of spamfighter.core View Source

Реализация основных классов доменов.

Class | DomainKeyError | В данном домене нет указанного значения.
Class | DomainPathError | Указанный путь в поддоменах отсутствует.
Class | DomainDuplicateError | У данного домена уже есть поддомен с таким же именем.
Class | BaseDomain | Домен - единица настроек, привязки локальных элементов
Function | getDefaultDomain | Получить домен по умолчанию, который является предком всех доменов.
Function | getDefaultDomainProvider | Получить провайдер домена по умолчанию.

def getDefaultDomain(): (source)
Получить домен по умолчанию, который является предком всех доменов.

Получаем через провайдер домена по умолчанию.

Returns | домен по умолчанию (type: `IDomain` )

def getDefaultDomainProvider(): (source)
Получить провайдер домена по умолчанию.

Загружаем как плагин, предсоставляющий интерфейс `IDefaultDomainProvider` с именем из конфига: config.plugins.domain.default_provider

Returns | провайдер домена по умолчанию (type: `IDefaultDomainProvider` )